/************ Update: Tables ***************/

/******************** Add Table: t_b_attachment ************************/

/* Build Table Structure */
CREATE TABLE t_b_attachment
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	name VARCHAR(100) 
		COMMENT '附件名称' NOT NULL,
	path VARCHAR(500) 
		COMMENT '路径' NOT NULL,
	type VARCHAR(30) 
		COMMENT '类型' NOT NULL,
	size DOUBLE 
		COMMENT '大小' NOT NULL,
	md5 VARCHAR(255) 
		COMMENT 'MD5' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_attachment ADD CONSTRAINT pkt_b_attachment
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_attachment COMMENT = '附件表';


/******************** Add Table: t_b_course ************************/

/* Build Table Structure */
CREATE TABLE t_b_course
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '课程编码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '课程名称' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_course ADD CONSTRAINT pkt_b_course
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_course COMMENT = '课程表';


/******************** Add Table: t_b_org ************************/

/* Build Table Structure */
CREATE TABLE t_b_org
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	level TINYINT 
		COMMENT '机构级别' NOT NULL,
	code VARCHAR(100) 
		COMMENT '机构代码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '机构名称' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	parent_id BIGINT 
		COMMENT '机构父id' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_org ADD CONSTRAINT pkt_b_org
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_org COMMENT = '学校机构表';


/******************** Add Table: t_b_partner ************************/

/* Build Table Structure */
CREATE TABLE t_b_partner
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	code VARCHAR(100) 
		COMMENT '合作方代码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '合作方名称' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	remark VARCHAR(1000) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_partner ADD CONSTRAINT pkt_b_partner
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_partner COMMENT = '合作厂家表';


/******************** Add Table: t_b_privilege ************************/

/* Build Table Structure */
CREATE TABLE t_b_privilege
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	name VARCHAR(50) 
		COMMENT '名称' NOT NULL,
	url VARCHAR(100) 
		COMMENT '地址' NOT NULL,
	type VARCHAR(50) 
		COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件' NOT NULL,
	parent_id BIGINT 
		COMMENT '父id' NULL,
	sequence INTEGER 
		COMMENT '序号' NULL,
	property VARCHAR(30) 
		COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用' NULL,
	remark VARCHAR(100) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_privilege ADD CONSTRAINT pkt_b_privilege
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_privilege COMMENT = '菜单和权限表';


/******************** Add Table: t_b_role ************************/

/* Build Table Structure */
CREATE TABLE t_b_role
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	name VARCHAR(100) 
		COMMENT '角色名称' NOT NULL,
	type VARCHAR(100) 
		COMMENT '角色类别，SUPER_SYSTEM：超管，SYSTEM：系统，SCHOOL：学校，PARTNER：合作方，PROJECT：项目' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	remark VARCHAR(1000) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL,
	property VARCHAR(30) 
		COMMENT '属性，SYSTEM：系统自带，CUSTOM：自定义' NOT NULL
);

/* Add Primary Key */
ALTER TABLE t_b_role ADD CONSTRAINT pkt_b_role
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_role COMMENT = '角色表';


/******************** Add Table: t_b_role_privilege ************************/

/* Build Table Structure */
CREATE TABLE t_b_role_privilege
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	role_id BIGINT 
		COMMENT '角色id' NOT NULL,
	privilege_id BIGINT 
		COMMENT '权限id' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否禁用，false：禁用，true：启用' NOT NULL
);

/* Add Primary Key */
ALTER TABLE t_b_role_privilege ADD CONSTRAINT pkt_b_role_privilege
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_role_privilege COMMENT = '角色默认权限表';


/******************** Add Table: t_b_school ************************/

/* Build Table Structure */
CREATE TABLE t_b_school
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	code VARCHAR(100) 
		COMMENT '学校代码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '学校名称' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	remark VARCHAR(1000) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_school ADD CONSTRAINT pkt_b_school
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_school COMMENT = '学校表';


/******************** Add Table: t_b_session ************************/

/* Build Table Structure */
CREATE TABLE t_b_session
(
	id VARCHAR(100) 
		COMMENT '主键' NOT NULL,
	identity VARCHAR(100) 
		COMMENT '用户标识' NOT NULL,
	type VARCHAR(50) 
		COMMENT '用户类型' NOT NULL,
	source VARCHAR(50) 
		COMMENT '访问来源' NOT NULL,
	platform VARCHAR(50) 
		COMMENT '设备分类' NOT NULL,
	device_id VARCHAR(100) 
		COMMENT '设备标识' NOT NULL,
	address VARCHAR(100) 
		COMMENT '登录IP地址' NOT NULL,
	access_token VARCHAR(50) 
		COMMENT '访问令牌' NOT NULL,
	last_access_time BIGINT 
		COMMENT '最近访问时间' NULL,
	last_access_ip VARCHAR(100) 
		COMMENT '最近访问IP地址' NULL,
	update_time BIGINT 
		COMMENT '令牌更新时间' NULL,
	expire_time BIGINT 
		COMMENT '令牌强制失效时间' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_session ADD CONSTRAINT pkt_b_session
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_session COMMENT = '会话表';


/******************** Add Table: t_b_task ************************/

/* Build Table Structure */
CREATE TABLE t_b_task
(
	id INTEGER 
		COMMENT '主键' NOT NULL,
	type VARCHAR(50) 
		COMMENT '任务类型，IMPORT_STUDENT_PHOTO：照片导入，EXPORT_STUDENT_PHOTO：照片导出，IMPORT_EXAM_STUDENT：考生导入，EXPORT_EXAM_STUDENT：考生导出，IMPORT_BATCH_PAPER：试卷批量导入，EXPORT_BATCH_PAPER：试卷批量导出，IMPORT_CUSTOM_TEMPLATE：模版批量导入，EXPORT_CUSTOM_TEMPLATE：模版批量导出，DOWNLOAD_BOX_STICKER：箱贴下载' NOT NULL,
	entity_id BIGINT 
		COMMENT '关联业务对象id' NULL,
	status VARCHAR(30) 
		COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成' NOT NULL,
	summary VARCHAR(2000) 
		COMMENT '实时摘要信息' NULL,
	progress DOUBLE 
		COMMENT '执行进度' NULL,
	result TINYINT 
		COMMENT '数据结果，true：成功，false：失败' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	import_file_name VARCHAR(100) 
		COMMENT '导入文件名' NULL,
	import_file_path VARCHAR(500) 
		COMMENT '导入文件路径' NULL,
	result_file_path VARCHAR(500) 
		COMMENT '导出文件路径' NULL,
	report_file_path VARCHAR(500) 
		COMMENT '报告路径' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	start_time BIGINT 
		COMMENT '开始时间' NULL,
	finish_time BIGINT 
		COMMENT '结束时间' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_task ADD CONSTRAINT pkt_b_task
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_task COMMENT = '导入导出任务表';


/******************** Add Table: t_b_user ************************/

/* Build Table Structure */
CREATE TABLE t_b_user
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NULL,
	partner_id BIGINT 
		COMMENT '合作方id' NULL,
	name VARCHAR(50) 
		COMMENT '姓名' NOT NULL,
	login_name VARCHAR(50) 
		COMMENT '登录名' NOT NULL,
	password VARCHAR(30) 
		COMMENT '密码' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL,
	remark VARCHAR(100) 
		COMMENT '备注' NULL
);

/* Add Primary Key */
ALTER TABLE t_b_user ADD CONSTRAINT pkt_b_user
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_user COMMENT = '用户表';


/******************** Add Table: t_b_user_role_privilege ************************/

/* Build Table Structure */
CREATE TABLE t_b_user_role_privilege
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	user_id BIGINT 
		COMMENT '用户id' NOT NULL,
	role_id BIGINT 
		COMMENT '角色id' NOT NULL,
	privilege_id BIGINT 
		COMMENT '权限id' NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否禁用，false：禁用，true：启用' NOT NULL
);

/* Add Primary Key */
ALTER TABLE t_b_user_role_privilege ADD CONSTRAINT pkt_b_user_role_privilege
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_b_user_role_privilege COMMENT = '用户角色权限表';


/******************** Add Table: t_e_activity ************************/

/* Build Table Structure */
CREATE TABLE t_e_activity
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '场次代码' NOT NULL,
	start_time BIGINT 
		COMMENT '考试开始时间' NOT NULL,
	end_time BIGINT 
		COMMENT '考试结束时间' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	sequence INTEGER 
		COMMENT '序号' NOT NULL
);

/* Add Primary Key */
ALTER TABLE t_e_activity ADD CONSTRAINT pkt_e_activity
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_activity COMMENT = '场次表';


/******************** Add Table: t_e_exam_student ************************/

/* Build Table Structure */
CREATE TABLE t_e_exam_student
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	student_id BIGINT 
		COMMENT '学生编号' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	activity_id BIGINT 
		COMMENT '场次id' NULL,
	course_code VARCHAR(100) 
		COMMENT '课程编码' NOT NULL,
	paper_type VARCHAR(20) DEFAULT 'A'
		COMMENT '卷型' NOT NULL,
	one_org_id BIGINT 
		COMMENT '一级机构id' NOT NULL,
	two_org_id BIGINT 
		COMMENT '二级机构id' NOT NULL,
	three_org_id BIGINT 
		COMMENT '三级机构id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '考生编码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '考生姓名' NOT NULL,
	identity VARCHAR(50) 
		COMMENT '准考证号' NULL,
	package_code VARCHAR(100) 
		COMMENT '任务包编号' NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	remark MEDIUMTEXT 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_e_exam_student ADD CONSTRAINT pkt_e_exam_student
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_exam_student COMMENT = '考生表';


/******************** Add Table: t_e_paper ************************/

/* Build Table Structure */
CREATE TABLE t_e_paper
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	course_code VARCHAR(100) 
		COMMENT '课程编码' NOT NULL,
	paper_type VARCHAR(20) DEFAULT 'A'
		COMMENT '卷型' NOT NULL,
	paper_template_type VARCHAR(30) 
		COMMENT '试卷模版类型，UNIVERSAL：通用，CUSTOM：自定义' NOT NULL,
	paper_template_id BIGINT 
		COMMENT '试卷模版id' NULL,
	question_card_template_type VARCHAR(30) 
		COMMENT '题卡模版类型，UNIVERSAL：通用，CUSTOM：自定义' NULL,
	question_card_template_id BIGINT 
		COMMENT '题卡模版id' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '更新时间' NULL,
	update_id BIGINT 
		COMMENT '更新人id' NULL,
	content MEDIUMTEXT 
		COMMENT '试卷预览json' NULL
);

/* Add Primary Key */
ALTER TABLE t_e_paper ADD CONSTRAINT pkt_e_paper
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_paper COMMENT = '试卷表';


/******************** Add Table: t_e_project ************************/

/* Build Table Structure */
CREATE TABLE t_e_project
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	partner_id BIGINT 
		COMMENT '合作方id' NOT NULL,
	user_id BIGINT 
		COMMENT '项目负责人id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '项目编码' NOT NULL,
	name VARCHAR(100) 
		COMMENT '项目名称' NOT NULL,
	status VARCHAR(30) 
		COMMENT '状态，NOT_START：未开始，PROCESSING：进行中，END：已关闭' NOT NULL,
	backup_field VARCHAR(4000) 
		COMMENT '备选字段' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '更新时间' NULL,
	update_id BIGINT 
		COMMENT '更新人id' NULL,
	end_time BIGINT 
		COMMENT '结束时间' NULL
);

/* Add Primary Key */
ALTER TABLE t_e_project ADD CONSTRAINT pkt_e_project
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_project COMMENT = '项目表';


/******************** Add Table: t_e_student ************************/

/* Build Table Structure */
CREATE TABLE t_e_student
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '学生编号' NOT NULL,
	name VARCHAR(100) 
		COMMENT '学生名称' NOT NULL,
	base_photo_path VARCHAR(500) 
		COMMENT '照片地址' NULL,
	idcard_number VARCHAR(30) 
		COMMENT '身份证号' NULL,
	mobile_number VARCHAR(30) 
		COMMENT '手机号' NULL,
	gender VARCHAR(20) 
		COMMENT '性别，MAN：男，WOMAN：女' NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_e_student ADD CONSTRAINT pkt_e_student
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_student COMMENT = '学生表';


/******************** Add Table: t_e_template ************************/

/* Build Table Structure */
CREATE TABLE t_e_template
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NULL,
	name VARCHAR(100) 
		COMMENT '名称' NOT NULL,
	template_type VARCHAR(30) 
		COMMENT '类型，IDENTITY：准考证，PAPER：试卷，QUESTION_CARD：题卡，PAPER_BAG：试卷袋，BOX_STICKER：箱贴，SIGN_SHEET：签到表' NOT NULL,
	size VARCHAR(30) 
		COMMENT '尺寸' NOT NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	content MEDIUMTEXT 
		COMMENT '模版预览json' NULL,
	paper_type VARCHAR(20) DEFAULT 'A'
		COMMENT '卷型' NULL,
	course_code VARCHAR(100) 
		COMMENT '课程编码' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_e_template ADD CONSTRAINT pkt_e_template
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_e_template COMMENT = '模版表';


/******************** Add Table: t_m_box_sticker_mission_package ************************/

/* Build Table Structure */
CREATE TABLE t_m_box_sticker_mission_package
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	box_sticker_set_id BIGINT 
		COMMENT '箱贴设置id' NOT NULL,
	box_sticker_no VARCHAR(100) 
		COMMENT '箱贴号' NOT NULL,
	express_no VARCHAR(100) 
		COMMENT '快递单号' NOT NULL,
	mission_package_bind TINYINT DEFAULT 1
		COMMENT '和任务包是否绑定，false：否，true：是' NOT NULL,
	mission_package_codes MEDIUMTEXT 
		COMMENT '任务包编号json' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_box_sticker_mission_package ADD CONSTRAINT pkt_m_box_sticker_mission_package
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_box_sticker_mission_package COMMENT = '箱贴任务关系表';


/******************** Add Table: t_m_box_sticker_set ************************/

/* Build Table Structure */
CREATE TABLE t_m_box_sticker_set
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	schoolId BIGINT 
		COMMENT '学校id' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	number INTEGER 
		COMMENT '数量' NOT NULL,
	start_no VARCHAR(50) 
		COMMENT '开始编号' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_box_sticker_set ADD CONSTRAINT pkt_m_box_sticker_set
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_box_sticker_set COMMENT = '箱贴设置表';


/******************** Add Table: t_m_event_log ************************/

/* Build Table Structure */
CREATE TABLE t_m_event_log
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '事件编号' NOT NULL,
	title VARCHAR(500) 
		COMMENT '标题' NULL,
	type VARCHAR(50) 
		COMMENT '类型，COMMON：普通，SUPPLY：补充，DELETE：删除' NOT NULL,
	`change` TINYINT DEFAULT 0
		COMMENT '数据是否变化，false：否，true：是' NOT NULL,
	content VARCHAR(2000) 
		COMMENT '内容' NULL,
	result VARCHAR(2000) 
		COMMENT '处理结果' NULL,
	remark VARCHAR(2000) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	print_change MEDIUMTEXT 
		COMMENT '印量变化json' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_event_log ADD CONSTRAINT pkt_m_event_log
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_event_log COMMENT = '事件记录表';


/******************** Add Table: t_m_mission ************************/

/* Build Table Structure */
CREATE TABLE t_m_mission
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	status VARCHAR(30) 
		COMMENT '状态，NOT_START：未开始，PROCESSING：数据生成中，FINISH：数据准备完成' NOT NULL,
	data_status VARCHAR(30) 
		COMMENT '数据生成状态，PAUSE：暂停，STOP：中止，CONTINUE：继续' NULL,
	enable TINYINT DEFAULT 1
		COMMENT '是否启用，false：停用，true：启用' NOT NULL,
	start_time BIGINT 
		COMMENT '数据生成开始时间' NULL,
	end_time BIGINT 
		COMMENT '数据生成结束时间' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	update_time BIGINT 
		COMMENT '修改时间' NULL,
	update_id BIGINT 
		COMMENT '修改人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_mission ADD CONSTRAINT pkt_m_mission
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_mission COMMENT = '任务表';


/******************** Add Table: t_m_mission_package ************************/

/* Build Table Structure */
CREATE TABLE t_m_mission_package
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NOT NULL,
	project_id BIGINT 
		COMMENT '项目id' NOT NULL,
	mission_id BIGINT 
		COMMENT '任务id' NOT NULL,
	mission_set_id BIGINT 
		COMMENT '任务设置id' NOT NULL,
	code VARCHAR(100) 
		COMMENT '任务包编号' NOT NULL,
	type VARCHAR(30) 
		COMMENT '类型，COMMON：常规，BACKUP：备份' NULL,
	status VARCHAR(30) 
		COMMENT '状态，NOT_START：未开始，PROCESSING：进行中，FINISH：已完成' NOT NULL,
	box_sticker_no VARCHAR(100) 
		COMMENT '箱贴号' NULL,
	express_no VARCHAR(100) 
		COMMENT '快递单号' NULL,
	pack_check TINYINT DEFAULT 0
		COMMENT '装袋校验，false：未校验，true：已校验' NOT NULL,
	box_check TINYINT DEFAULT 0
		COMMENT '装箱校验，false：未校验，true：已校验' NOT NULL,
	post_check TINYINT DEFAULT 0
		COMMENT '邮寄校验，false：未校验，true：已校验' NOT NULL,
	context_attachment_id BIGINT 
		COMMENT '最终生成的附件id' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL,
	start_time BIGINT 
		COMMENT '文件开始生成时间' NULL,
	update_id BIGINT 
		COMMENT '执行人id' NULL,
	path VARCHAR(500) 
		COMMENT '任务包存放地址' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_mission_package ADD CONSTRAINT pkt_m_mission_package
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_mission_package COMMENT = '任务包表';


/******************** Add Table: t_m_mission_set ************************/

/* Build Table Structure */
CREATE TABLE t_m_mission_set
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	mission_id BIGINT 
		COMMENT '任务id' NOT NULL,
	print_content MEDIUMTEXT 
		COMMENT '打印设置json' NOT NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_m_mission_set ADD CONSTRAINT pkt_m_mission_set
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_m_mission_set COMMENT = '任务设置表';


/******************** Add Table: t_s_log ************************/

/* Build Table Structure */
CREATE TABLE t_s_log
(
	id BIGINT 
		COMMENT '主键' NOT NULL,
	school_id BIGINT 
		COMMENT '学校id' NULL,
	project_id BIGINT 
		COMMENT '项目id' NULL,
	mission_id BIGINT 
		COMMENT '任务id' NULL,
	mission_package_id BIGINT 
		COMMENT '任务包id' NULL,
	type VARCHAR(50) 
		COMMENT '类型，主要记录状态流转和数据验证' NULL,
	summary VARCHAR(2000) 
		COMMENT '实时摘要信息' NULL,
	remark VARCHAR(1000) 
		COMMENT '备注' NULL,
	create_time BIGINT 
		COMMENT '创建时间' NULL,
	create_id BIGINT 
		COMMENT '创建人id' NULL
);

/* Add Primary Key */
ALTER TABLE t_s_log ADD CONSTRAINT pkt_s_log
	PRIMARY KEY (id);

/* Add Comments */
ALTER TABLE t_s_log COMMENT = '系统日志表';